#!/usr/bin/env python3
# vim: set shiftwidth=4 softtabstop=4:
"""Tools to help build an image
"""
import logging
import os
import sys
from subprocess import call

from .config import Config
from .list_modules import list_modules
from .parsing import apply, basic_parser

_logger = logging.getLogger(__name__)

__version__ = "2.0.0"
__date__ = "2020-06-30"
__updated__ = "2021-12-10"


def __parser():
    program_version = __version__
    program_build_date = str(__updated__)
    program_version_message = "%%(prog)s %s (%s)" % (
        program_version,
        program_build_date,
    )
    program_shortdesc = __doc__.split(".", maxsplit=1)[0]
    program_license = """%s

      Created by Vincent Hatakeyama on %s.
      Copyright 2020, 2021 XCG Consulting. All rights reserved.

      Licensed under the MIT License

      Distributed on an "AS IS" basis without warranties
      or conditions of any kind, either express or implied.

    USAGE
    """ % (
        program_shortdesc,
        str(__date__),
    )
    parser = basic_parser(program_license, program_version_message)
    return parser


def main(argv=None):
    """Copy modules for a build, callable version that parses arguments"""
    parser = __parser()
    nmspc = parser.parse_args(argv)
    apply(nmspc)
    copy()
    return 0


def copy():
    """Copy modules for a build"""
    c = Config()
    modules = [os.path.realpath(module) for module in c.modules]
    # copy files
    target = "odoo_modules"
    _logger.info("Copying Odoo modules files to %s", target)
    if not os.path.exists(target):
        os.mkdir(target)
    cmd = (
        [
            "rsync",
            "--delete",
            "--cvs-exclude",
            "--include=core",
            "--exclude=.hg*",
            "--exclude=.git*",
            "--links",
            "--exclude='*.pyc'",
            "-r",
            "--times",
        ]
        + modules
        + [target]
    )
    _logger.debug(" ".join(cmd))
    call(cmd)
    # copy setup files to odoo_setup
    source = "setup/"
    target = "odoo_setup"
    if os.path.exists(source):
        _logger.info("Copying Odoo %s files to %s", source, target)
        if not os.path.exists(target):
            os.mkdir(target)
        cmd = [
            "rsync",
            "--delete",
            "--cvs-exclude",
            "--include=core",
            "--exclude=.hg*",
            "--exclude=.git*",
            "--copy-links",
            "--exclude='*.pyc'",
            "-r",
            "--times",
        ] + [source, target]
        _logger.debug(" ".join(cmd))
        call(cmd)

    list_modules()


if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))
